Pounce
======

Pounce allows you to push resources to clients over HTTP2.

Installation
~~~~~~~~~~~~

.. code-block:: console

    $ pip install django-pounce

Compatibility
~~~~~~~~~~~~~
* Django 1.11
* Python 3.5
